@@ -8,11 +8,12 @@ Information describing the project.
 package = "gn2pg_client"
 project = "GeoNature 2 PostgreSQL Client application"
 project_no_spaces = project.replace(" ", "")
-version = "0.1.2-dev"
+version = "1.1.2"
 description = "Import tool from GeoNature to a PostgreSQL database through Export module API (client side)"
-authors = ["@lpofredc"]
+authors = ["@lpofredc (LPOAuRA)"]
 authors_string = ", ".join(authors)
 emails = ["frederic.cloitre@lpo.fr"]
 license = "AGPL-3.0"
-copyright = "2021 " + authors_string
-url = "https://github.com/lpoaura/gn2pg_client"
+copyright = "2022 " + authors_string
+url = "https://github.com/lpoaura/GN2PG"
+docs = "https://gn2pg.readthedocs.io/en/latest/"
