@@ -20,6 +20,7 @@ from sqlalchemy import (
     exc,
     func,
     select,
+    text,
 )
 from sqlalchemy.dialects.postgresql import JSONB, UUID, insert
 from sqlalchemy.engine.url import URL
@@ -375,7 +376,8 @@ class PostgresqlUtils:
         self._metadata = MetaData(schema=dbschema)
         # self._metadata.reflect(self._db)
         try:
-            conn.execute(sqlscript)
+            # logger.debug(sqlscript)
+            conn.execute(text(sqlscript))
             logger.info(_(f"script {script} successfully applied"))
         except Exception as e:
             logger.critical(f"{str(e)}")
@@ -478,8 +480,8 @@ class StorePostgresql:
         except exc.StatementError as error:
             self.error_log(controler, elem, str(error))
             logger.critical(
-                f"One error occured for data from source {self._config.std_name} whith "
-                f"{id_key_name} = {elem[id_key_name]}"
+                f"One error occured for data from source {self._config.std_name} with "
+                f"{id_key_name} = {elem[id_key_name]}. Error message is {str(error)}"
             )
 
     def store_data(
